#' @name SoaresEx18
#' @title Valores de creatinina fosfocinase (CFC) em 360 pacientes.
#' @description Em um hospital do coração, foram analisados os valores 
#'     de CFC (crestinina fosfocinase) de 360 pacientes, sendo 230 com 
#'     infarto agudo do miocárdio.  
#' @format Um \code{data.frame} com 6 observações e 3 variáveis.
#'
#' \describe{
#'
#' \item{\code{cfc}}{Indice dos valores de CFC.}
#'
#' \item{\code{ia}}{Infarto agudo presente ou não presente.}
#'
#' \item{exp}{Variável explicativa com os valores obtidos.}
#'
#' }
#' @keywords AAS
#' @source Introdução à estatística médica/José Francisco Soares e 
#'     Arminda lucia Siqueira. 2.ed. Belo Horizonte: COOPMED, 2002. 
#'     Ex 18, pg 127.
#' @examples
#'
#' library(lattice)
#' data(SoaresEx18)
#'
#' coleta <- xtabs(exp ~ cfc + ia, data = SoaresEx18)
#' barchart(coleta, horizontal = FALSE, 
#'     stack = FALSE,
#'     scales = list(x = list(labels = c("CFC < 80","CFC >= 280",
#'     "80 <= CFC < 280"))),
#'     ylab = "Frequência",
#'     xlab = "CFC",
#'     main = "Valores de creatinina fosfocinase (CFC) em 360 pacientes",
#'     auto.key = list(corner = c(0.75, 0.95), 
#'     text = c("não", 
#'     'sim')))
#' 
#' 
#'
NULL
