#' @name SoaresEx6.17
#' @title Relação entre a Depressão e o Desejo pela Morte de Pacientes
#'     com Câncer Terminal
#' @description Um estudo feito por Chochinov et al. (1995) contou com a
#'     participação de 190 pacientes de dois hospitais em Winnipeg,
#'     Canadá, com diagnóstico primário de câncer terminal, admitidos no
#'     período de coletas de dados. Uma das preocupações era verificar a
#'     existência de relação entre o desejo de morte relatado por alguns
#'     deles e a depressão diagnosticada em alguns casos.
#' @format Um \code{data.frame} com 4 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{dpm}}{Desejo pela morte ausente ou presente nos pacientes
#'     do estudo.}
#'
#' \item{\code{dpss}}{Depressão presente ou ausente nos pacientes do
#'     estudo.}
#'
#' \item{\code{freq}}{Frequência de casos em cada combinação.}
#'
#' }
#' @keywords AAS
#' @source SOARES; SIQUEIRA (2002), exercício 17, pág. 230.
#' @references CHOCHINOV, H. M., WILSON, K.G., ENNS, M. et al. Desire
#'     for death in the terminal ill. \emph{The American Journal of
#'     Psychiatry}, v.152, p.1185-91, 1995.
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresEx6.17)
#' str(SoaresEx6.17)
#'
#' names(SoaresEx6.17)[3] <- "freq"
#' dado <- xtabs(freq ~ dpm + dpss, data = SoaresEx6.17)
#' mosaicplot(dado)
#'
#' barchart(dado,
#'          horizontal = FALSE,
#'          stack = FALSE,
#'          scales = list(x = list(labels = c("Ausente", "Presente"))),
#'          ylab = "Frequência",
#'          xlab = "Depressão",
#'          auto.key = list(text = c("Desejo pela morte ausente",
#'                                   "Desejo pela morte presente")))
#'
NULL
