#' @name SoaresEx6.18
#' @title A Transferência do Álcool para o Leite Materno
#' @description O consumo de pequenas quantidades de álcool tem sido
#'     recomendado a mulheres que amamentam a fim de ajudar à lactação.
#'     A ocorrência de alteração nas características sensoriais do leite
#'     ou no comportamento dos lactentes foi objeto de estudo de
#'     Mennella e Beauchamp (1991). Durante dois dias, com intervalo de
#'     uma semana, doze mulheres consumiram suco de laranja puro ou
#'     contendo etanol (0.3 g/Kg de massa corporal) antes de amamentarem 
#'     suas crianças e meia-hora após ter sido obtida uma amostra do 
#'     leite. Metade das mulheres bebeu o etanol no suco de laranja no 
#'     primeiro dia de teste e o suco de laranja puro no segundo. A 
#'     ordem foi invertida para as seis mulheres remanescentes. Amostras
#'     de leite para o estudo foram obtidas 30 minutos, 1, 2, e 3 horas 
#'     após o consumo da bebida, de modo a interromper o mínimo possível
#'     a amamentação. 
#' @format Um \code{data.frame} com 4 observações e 6 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{var}}{Variável analisada no estudo. Neste caso, o leite
#'     ingerido pela criança e o tempo de duração da amamentação.}
#'
#' \item{\code{exp}}{Variável explicativa com os valores em ml diante do
#'     leite ingerido e em minutos para o tempo.}
#'
#' \item{\code{ba}}{Bebida alcoólica ingerida ou não ingerida.}
#'
#' \item{\code{exp}}{Variável explicativa com os valores obtidos.}
#'
#' \item{\code{teste.t}}{Valor obtido com o teste-t.}
#'
#' \item{\code{valor.p}}{Valor-p utilizado no estudo.}
#'
#' }
#' @keywords AAS
#' @source SOARES; SIQUEIRA, (2002), tabela 18, pág. 230.
#' @references MENNELLA, J. A., BEAUCHAMP, G. K. The transfer of alcohol
#'     to human milk. \emph{The New England Journal of Medicine}, v.325,
#'     p.981-5, 1991.
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresEx6.18)
#' str(SoaresEx6.18)
#'
#' dados <- xtabs(exp ~ var + ba, data = SoaresEx6.18)
#' addmargins(dados)
#'
#' barchart(dados,
#'          horizontal = FALSE,
#'          stack = FALSE,
#'          scales = list(x = list(labels = c("Leite ingerido (mL)",
#'                                            "Tempo (min)"))),
#'          ylab = "Frequência",
#'          xlab = "Variável",
#'          auto.key = list(text = c("Bebida alcoólica não ingerida",
#'                                   "Bebida alcoólica ingerida")))
#'
NULL
