#' @name SoaresEx6.19
#' @title Incidência de Suicídio como Causa de Morte para Poetas e
#'     Escritores de Ficção
#' @description Em 1992, Ludwig fez um estudo na qual compara o
#'     comportamento criativo e psicopatológico entre diversos grupos
#'     profissionais, a partir de pelo menos um fonte bibliográfica bem
#'     documentada e bem estudada. Mais de 1000 personalidades
#'     eminentes, já falecidas e que viveram pelo menos uma parte de
#'     suas vidas no século XX foram divididas em dezenove categorias
#'     profissionais e observações comportamentais. Uma característica
#'     estudada foi a existência de diferenças na psicopatologia para
#'     imigrantes do grupo artístico, tais como poetas e escritores de
#'     ficção.
#' @format Um \code{data.frame} com 4 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{cm}}{Causa de morte.}
#'
#' \item{\code{prof}}{Profissão avaliada.}
#'
#' \item{\code{freq}}{Frequência de casos tem cada situação.}
#'
#' }
#' @keywords AAS
#' @source SOARES; SIQUEIRA (2002), exercício 19, capítulo 6, pág. 231.
#' @references LUDWING, A. M. Creative achievement and psychology:
#'     comparison among professions. \emph{The American Journal of
#'     Psychotherapy}, v.46, p.330-56, 1992.
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresEx6.19)
#' str(SoaresEx6.19)
#'
#' a <- xtabs(freq ~ cm + prof, data = SoaresEx6.19)
#' addmargins(a)
#'
#' barchart(a,
#'          horizontal = FALSE,
#'          stack = FALSE,
#'          scales = list(x = list(labels = c("Outras", "Suicídio"))),
#'          ylab = "Frequência",
#'          xlab = "Causa da morte",
#'          auto.key = list(text = c("Escritores de ficção",
#'                                   "Poetas")))
#'
NULL
