#' @name SoaresTb6.1
#' @title Sobreviência de Pacientes Tratados com AZT ou Placebo
#' @description Em 1987, FISCHL publicou o primeiro relato de um ensaio
#'     clínico que comprovou a eficácia do fármaco zidovudina (AZT) para
#'     prolongar a vida de pacientes com AIDS. Na tabela é apresentado
#'     os dados entre a relação dos pacientes que receberam o AZT e o
#'     placebo e permaneceram vivos ou mortos durante o experimento.
#' @format Um \code{data.frame} com 4 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{grp}}{Grupo de pacientes que receberam o zidozudina (AZT)
#'     ou placebo.}
#'
#' \item{\code{sit}}{Situação dos pacientes com AIDS após o uso dos
#'     fármacos no que diz respeito ao prolongamento de suas vidas.}
#'
#' \item{freq}{Número de casos em cada situação.}
#'
#' }
#' @keywords TC
#' @source SOARES; SIQUEIRA (2002), tabela 6.1, pág. 177.
#' @references FISCHL, M. A., RICHMAN, D. D., GRIECO, M. H. et al. The
#'     efficacy of azidothymidine (AZT) in treatment of patients with
#'     AIDS and AIDS-related complez. A doubleblind, placebo-controlled
#'     trial. \emph{The New England Journal of Medicine}, v.317, n.4
#'     p.185-91, 1987.
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresTb6.1)
#' str(SoaresTb6.1)
#'
#' dados <- xtabs(freq ~ grp + sit, data = SoaresTb6.1)
#' addmargins(dados)
#'
#' barchart(dados,
#'          horizontal = FALSE,
#'          stack = FALSE,
#'          scales = list(x = list(labels = c("AZT", "Placebo"))),
#'          ylab = "Frequência",
#'          xlab = "Grupo",
#'          auto.key = list(text = c("Morto", "Vivo")))
#'
NULL
