#' @name SoaresTb6.15
#' @title Escore Final na Escala MADRS de Pacientes dos Dois Grupos
#'     Admitidos Tratados com Tianeptina
#' @description A tianeptina é um fármaco antidepressivo do grupo dos
#'     tricíclicos. Rocha (1995) relata os resultados de um ensaio
#'     clínico aleatorizado, duplo-cego, realizado com o objetivo de
#'     comparar a tianeptina com o placebo. Participaram deste ensaio
#'     pacientes de Belo Horizonte, Rio de Janeiro, e Campinas. O ensaio
#'     consistiu em administrar a droga a dois grupos de pacientes,
#'     compostos de forma aleatória, e quantificar a depressão através
#'     da escala de Montgomery-Asberg (MADRS), em que os valores maiores
#'     indicam maior gravidade da depressão. O escore foi obtido para
#'     cada paciente 7, 14, 21, 28 e 42 dias após o início do ensaio.
#' @format Um \code{data.frame} com 32 observações e 2 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{grp}}{Grupos de pacientes segundo recebimento da
#'     tieneptina.}
#'
#' \item{\code{esc}}{Escore final obtido pelo paciente após os 42 dias.}
#'
#' }
#' @keywords TC
#' @source SOARES; SIQUEIRA (2002), tabela 6.15, pág. 197.
#' @references ROCHA. F. L. Eficácia e tolerabilidade no tratamento de
#'     episódios depressivos maiores: estudo multicêntrico, duplo-cego,
#'     controlado com placebo. Belo Horizonte: Faculdade de Medicina da
#'     UFMG, 1995. 156 p. (Dissertação, Mestrado em Medicina Preventiva
#'     e Social).
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresTb6.15)
#' str(SoaresTb6.15)
#'
#' xyplot(esc ~ grp,
#'        data = SoaresTb6.15,
#'        type = c("p", "a"),
#'        grid = TRUE,
#'        jitter.x = TRUE,
#'        xlab = "Tratamento com tieneptina",
#'        ylab = "Escores dos pacientes")
#'
NULL
