#' @name SoaresTb6.20
#' @title Escores do Grupo Tianeptina no Primeiro e Último Dia
#' @description A tianeptina é um fármaco antidepressivo do grupo dos
#'     tricíclicos. Rocha (1995) relata os resultados de um ensaio
#'     clínico aleatorizado, duplo-cego, realizado com o objetivo de
#'     comparar a tianeptina com o placebo. O ensaio consistiu em
#'     administrar a droga a dois grupos de pacientes, compostos de
#'     forma aleatória, e quantificar a depressão através da escala de
#'     Montgomery-Asberg (MADRS). Além disso, Rocha verificou se houve
#'     diminuição do escore de depressão entre os pacientes de um dos
#'     grupos (tianeptina) durante o desenvolvimento do estudo. Os dados
#'     apresentados são escores atribuídos a 16 pacientes do grupo
#'     tianeptina que foram admitidos em Belo Horizonte no primeiro dia
#'     e no último dia.
#' @format Um \code{data.frame} com 16 observações e 2 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{pd}}{Escore obtido pelo paciente no primeiro dia.}
#'
#' \item{\code{ud}}{Escore obtido pelo paciente no último dia.}
#'
#' }
#' @keywords AAS
#' @source SOARES; SIQUEIRA, (2002), tabela 20, pág. 207.
#' @references ROCHA. F. L. Eficácia e tolerabilidade no tratamento de
#'     episódios depressivos maiores: estudo multicêntrico, duplo-cego,
#'     controlado com placebo. Belo Horizonte: Faculdade de Medicina da
#'     UFMG, 1995. 156 p. (Dissertação, Mestrado em Medicina Preventiva
#'     e Social).
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresTb6.20)
#' str(SoaresTb6.20)
#'
#' xyplot(ud ~ pd,
#'        data = SoaresTb6.20,
#'        type = c("p", "a"),
#'        jitter.x = TRUE,
#'        xlab = "Pacientes do grupo tianeptina",
#'        ylab = "Escores dos pacientes")
#'
NULL

